
import unittest

from util import elem, elem_find_children

class ElemTest(unittest.TestCase):
    def test_single(self):
        assert elem('foo')().toXml() == '<foo/>'

    def test_attribute(self):
        assert elem('foo', x='1')().toXml() == "<foo x='1'/>"

    def test_content(self):
        assert elem('foo', x='1')(u'hello').toXml() == \
                "<foo x='1'>hello</foo>"

    def test_children(self):
        assert elem('foo', x='1')(u'hello',
            elem('http://foo.org', 'bar', y='2')(u'bye')).toXml() == \
                "<foo x='1'>hello<bar xmlns='http://foo.org' y='2'>bye</bar></foo>"

    def test_ns(self):
        stanza = elem('uri1', 'foo')(
            elem('uri1', 'bar1'),
            elem('uri2', 'bar2'),
            elem('bar3'))

        assert len(stanza.children) == 3

        ns = {'bar1': 'uri1', 'bar2': 'uri2', 'bar3': 'uri1'}
        for e in stanza.children:
            assert e.uri == ns[e.name]

class ElemFindChildrenTest(unittest.TestCase):
    def test_simple(self):
        stanza = elem('foo')(
            elem('uri1', 'bar'),
            elem('uri1', 'bar'),
            elem('uri2', 'bar'))

        childs = [e for e in elem_find_children(stanza, 'uri1', 'bar')]
        assert map(lambda e: e.name, childs) == ['bar', 'bar']

    def test_ns(self):
        stanza = elem('uri1', 'foo')(
            elem('uri1', 'bar'),
            elem('uri2', 'bar'),
            elem('bar'))

        childs = [e for e in elem_find_children(stanza, 'uri1', 'bar')]
        assert map(lambda e: e.name, childs) == ['bar', 'bar']
